@@ -7,6 +7,8 @@ import logging
 import sys
 import json
 import os
+import ScratchEncoder
+import websocket
 try:
     ws = websocket.WebSocket()
 except TypeError:
